"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _ModalView = _interopRequireDefault(require("./ModalView"));
var _SliderModalView = _interopRequireDefault(require("./SliderModalView"));
var _EvenRegister = _interopRequireDefault(require("./EvenRegister"));
var _functions = require("../functions");
var _styles = _interopRequireDefault(require("../styles"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
const MainModal = props => {
  const {
    visible = true,
    wrapStyle,
    defaultModalProps
  } = props;
  const {
    width
  } = (0, _reactNative.useWindowDimensions)();
  const {
    containerStyle: defaultContainerStyle,
    wrapContainerStyle: defaultWrapContainerStyle,
    backdropStyle: defaultBackdropStyle,
    ..._defaultModalProps
  } = defaultModalProps || {};
  const [modalListState, setModalListState] = (0, _react.useState)([]);
  (0, _react.useEffect)(() => {
    _EvenRegister.default.on('open-nested-modal', modalProps => {
      setModalListState(_state => {
        return _state.concat(modalProps);
      });
    });
    _EvenRegister.default.on('close-nested-modal', args => {
      setModalListState(_state => {
        return _state.map(el => {
          if (el.id === args.id) {
            return {
              ...el,
              visible: false
            };
          }
          return el;
        });
      });
    });
    _EvenRegister.default.on('update-nested-modal', modalProps => {
      setModalListState(_state => {
        return _state.map(el => {
          if (el.id === modalProps.id) {
            return modalProps;
          }
          return el;
        });
      });
    });
    return () => {
      _EvenRegister.default.rm('open-nested-modal');
      _EvenRegister.default.rm('close-nested-modal');
      _EvenRegister.default.rm('update-nested-modal');
    };
  }, []);
  const _onCloseModal = modalProps => () => {
    var _modalProps$onClose;
    (_modalProps$onClose = modalProps.onClose) === null || _modalProps$onClose === void 0 || _modalProps$onClose.call(modalProps);
    setModalListState(_state => _state.filter(item => item.id !== modalProps.id));
  };
  if (!visible || modalListState == undefined || modalListState.length < 1) return null;
  return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [_styles.default.modalWrapContainer, wrapStyle]
  }, modalListState.map(item => {
    const {
      id,
      modalType,
      containerStyle,
      wrapContainerStyle,
      backdropStyle,
      autoTransform,
      transformBreakPoint,
      ..._modalProps
    } = item;
    const _modalType = (0, _functions.getAutoTransformModalType)(!!autoTransform, modalType, width, transformBreakPoint);
    const _modalContentStyles = !!autoTransform && _modalType === 'fade' ? {
      width: (0, _functions.getAutoTransformWidth)(width, transformBreakPoint),
      paddingLeft: 0,
      paddingRight: 0
    } : undefined;
    if (_modalType === 'slide') {
      return /*#__PURE__*/_react.default.createElement(_SliderModalView.default, _extends({
        key: id,
        containerStyle: [defaultContainerStyle, containerStyle],
        wrapContainerStyle: [defaultWrapContainerStyle, wrapContainerStyle],
        backdropStyle: [defaultBackdropStyle, backdropStyle]
      }, _defaultModalProps, _modalProps, {
        onClose: _onCloseModal(item)
      }));
    }
    return /*#__PURE__*/_react.default.createElement(_ModalView.default, _extends({
      key: id,
      containerStyle: [defaultContainerStyle, _modalContentStyles, containerStyle],
      wrapContainerStyle: [defaultWrapContainerStyle, wrapContainerStyle],
      backdropStyle: [defaultBackdropStyle, backdropStyle]
    }, _defaultModalProps, _modalProps, {
      onClose: _onCloseModal(item)
    }));
  }));
};
var _default = MainModal;
exports.default = _default;
//# sourceMappingURL=ModalSection.js.map