"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _reactNativeNtcPressable = require("react-native-ntc-pressable");
var _functions = require("../functions");
var _styles = _interopRequireDefault(require("../styles"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
const ANIMATION_DURATION = 200;
const DEFAULT_HEIGHT_RATIO = 0.7;
const ModalView = props => {
  const {
    containerStyle,
    wrapContainerStyle,
    backdropStyle,
    id,
    visible,
    close,
    onOpen,
    onDidOpen,
    onClose,
    maxHeight,
    keyboardHeight,
    safeAreaInsets,
    onMainContentLayout,
    blurToClose = true,
    children,
    wrapContent,
    bottomOffset
  } = props;
  const localData = (0, _react.useRef)({
    isRunningAnimation: false,
    id: id || (0, _functions.generateId)()
  });
  const [backdropOpacityState] = (0, _react.useState)(new _reactNative.Animated.Value(0));
  const [visibleState, setVisibleState] = (0, _react.useState)(false);
  const {
    height
  } = (0, _reactNative.useWindowDimensions)();
  const _maxHeight = maxHeight ? maxHeight : height * DEFAULT_HEIGHT_RATIO;
  const _bottomOffset = bottomOffset ?? height * 0.15;
  const _marginBottom = !keyboardHeight || keyboardHeight + 10 < _bottomOffset ? _bottomOffset : keyboardHeight + 10;
  (0, _react.useEffect)(() => {
    if (visible) {
      if (localData.current.isRunningAnimation) {
        _dropAnimation();
        setTimeout(() => {
          _openModal();
        }, 100);
      } else {
        _openModal();
      }
    } else {
      if (localData.current.isRunningAnimation) {
        _dropAnimation();
        setTimeout(() => {
          _closeModal();
        }, 100);
      } else {
        _closeModal();
      }
    }
  }, [visible]);
  const _openModal = () => {
    setVisibleState(true);
    onOpen === null || onOpen === void 0 || onOpen(localData.current.id);
    localData.current.isRunningAnimation = true;
    _reactNative.Animated.timing(backdropOpacityState, {
      toValue: 1,
      duration: ANIMATION_DURATION,
      useNativeDriver: true
    }).start(() => {
      localData.current.isRunningAnimation = false;
      onDidOpen === null || onDidOpen === void 0 || onDidOpen(localData.current.id);
    });
  };
  const _closeModal = () => {
    localData.current.isRunningAnimation = true;
    _reactNative.Animated.timing(backdropOpacityState, {
      toValue: 0,
      duration: ANIMATION_DURATION,
      delay: 0,
      useNativeDriver: true
    }).start(() => {
      setVisibleState(false);
      localData.current.isRunningAnimation = false;
      onClose === null || onClose === void 0 || onClose(localData.current.id);
    });
  };
  const _dropAnimation = () => {
    // @ts-ignore
    _reactNative.Animated.timing(backdropOpacityState).stop();
  };
  const _onBackdropPress = () => {
    close === null || close === void 0 || close();
  };
  const _onModalContentLayout = onMainContentLayout ? e => {
    e.persist();
    onMainContentLayout(e, localData.current.id);
  } : undefined;
  if (!visibleState) return null;
  return /*#__PURE__*/_react.default.createElement(_reactNative.Animated.View, {
    style: [_styles.default.modalWrapContainer, {
      opacity: backdropOpacityState
    }, wrapContainerStyle]
  }, /*#__PURE__*/_react.default.createElement(_reactNativeNtcPressable.TouchableWithoutFeedback, {
    onPress: _onBackdropPress,
    disabled: !blurToClose
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [{
      height: '100%',
      width: '100%',
      position: 'absolute',
      bottom: 0,
      backgroundColor: 'rgba(0,0,0,0.7)'
    }, backdropStyle]
  })), /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [{
      backgroundColor: '#ffffff',
      marginTop: 'auto',
      marginBottom: _marginBottom,
      width: '95%',
      alignSelf: 'center',
      borderRadius: 20,
      overflow: 'hidden',
      maxHeight: _maxHeight,
      flexShrink: 1
    }, !!safeAreaInsets && !!keyboardHeight && {
      top: safeAreaInsets.top,
      marginBottom: _marginBottom + safeAreaInsets.top
    }, containerStyle],
    onLayout: _onModalContentLayout
  }, children), wrapContent);
};
var _default = ModalView;
exports.default = _default;
//# sourceMappingURL=ModalView.js.map