"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _reactNativeNtcPressable = require("react-native-ntc-pressable");
var _functions = require("../functions");
var _styles = _interopRequireDefault(require("../styles"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
const ANIMATION_BOUNCINESS = 1;
const ANIMATION_SPEED = 15;
const ANIMATION_DURATION = 200;
const SliderModal = props => {
  const {
    containerStyle,
    wrapContainerStyle,
    backdropStyle,
    id,
    visible,
    close,
    onOpen,
    onDidOpen,
    onClose,
    onMainContentLayout,
    children,
    wrapContent,
    keyboardHeight,
    safeAreaInsets,
    blurToClose = true,
    maxHeight = '95%'
  } = props;
  const myLocalData = (0, _react.useRef)({
    isRunningAnimation: false,
    id: id || (0, _functions.generateId)()
  });
  const {
    height
  } = (0, _reactNative.useWindowDimensions)();
  const [state] = (0, _react.useState)({
    backdropOpacity: new _reactNative.Animated.Value(0),
    contentTranslateY: new _reactNative.Animated.Value(height)
  });
  const [contentLayout, setContentLayout] = (0, _react.useState)({
    height
  });
  const [visibleState, setVisibleState] = (0, _react.useState)(false);
  (0, _react.useEffect)(() => {
    if (visible) {
      if (myLocalData.current.isRunningAnimation) {
        _dropAnimation();
        setTimeout(() => {
          _openModal();
        }, 100);
      } else {
        _openModal();
      }
    } else {
      if (myLocalData.current.isRunningAnimation) {
        _dropAnimation();
        setTimeout(() => {
          _closeModal();
        }, 100);
      } else {
        _closeModal();
      }
    }
  }, [visible]);
  const _openModal = () => {
    setVisibleState(true);
    onOpen === null || onOpen === void 0 || onOpen(id);
    myLocalData.current.isRunningAnimation = true;
    _reactNative.Animated.timing(state.backdropOpacity, {
      toValue: 1,
      duration: ANIMATION_DURATION,
      useNativeDriver: true
    }).start();
    _reactNative.Animated.spring(state.contentTranslateY, {
      toValue: 0,
      speed: ANIMATION_SPEED,
      bounciness: ANIMATION_BOUNCINESS,
      useNativeDriver: true
    }).start(() => {
      myLocalData.current.isRunningAnimation = false;
      onDidOpen === null || onDidOpen === void 0 || onDidOpen(id);
    });
  };
  const _closeModal = () => {
    myLocalData.current.isRunningAnimation = true;
    _reactNative.Animated.spring(state.contentTranslateY, {
      toValue: contentLayout.height,
      speed: ANIMATION_SPEED,
      bounciness: ANIMATION_BOUNCINESS,
      useNativeDriver: true
    }).start();
    _reactNative.Animated.timing(state.backdropOpacity, {
      toValue: 0,
      duration: ANIMATION_DURATION,
      delay: 0,
      useNativeDriver: true
    }).start(() => {
      setVisibleState(false);
      myLocalData.current.isRunningAnimation = false;
      onClose === null || onClose === void 0 || onClose(id);
    });
  };
  const _dropAnimation = () => {
    // @ts-ignore
    _reactNative.Animated.timing(state.backdropOpacity).stop();
    // @ts-ignore
    _reactNative.Animated.spring(state.contentTranslateY).stop();
  };
  const _onBackdropPress = () => {
    close === null || close === void 0 || close();
  };
  const _onModalContentLayout = e => {
    var _e$nativeEvent;
    e.persist();
    onMainContentLayout === null || onMainContentLayout === void 0 || onMainContentLayout(e, id);
    const layout = (_e$nativeEvent = e.nativeEvent) === null || _e$nativeEvent === void 0 ? void 0 : _e$nativeEvent.layout;
    setContentLayout(layout);
  };
  if (!visibleState) return null;
  return /*#__PURE__*/_react.default.createElement(_reactNative.Animated.View, {
    style: [_styles.default.modalWrapContainer, {
      opacity: state.backdropOpacity,
      justifyContent: 'flex-end'
    }, wrapContainerStyle]
  }, /*#__PURE__*/_react.default.createElement(_reactNativeNtcPressable.TouchableWithoutFeedback, {
    onPress: _onBackdropPress,
    disabled: !blurToClose
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [{
      height: '100%',
      width: '100%',
      position: 'absolute',
      top: 0,
      backgroundColor: 'rgba(0,0,0,0.7)'
    }, backdropStyle]
  })), /*#__PURE__*/_react.default.createElement(_reactNative.Animated.View, {
    style: [{
      backgroundColor: '#ffffff',
      width: '100%',
      maxHeight,
      overflow: 'hidden',
      borderTopLeftRadius: 20,
      borderTopRightRadius: 20,
      flexShrink: 1,
      transform: [{
        translateY: state.contentTranslateY
      }]
    }, !!safeAreaInsets && {
      marginTop: safeAreaInsets.top,
      paddingBottom: safeAreaInsets.bottom,
      paddingLeft: safeAreaInsets.left,
      paddingRight: safeAreaInsets.right
    }, containerStyle, !!keyboardHeight && {
      paddingBottom: keyboardHeight
    }],
    onLayout: _onModalContentLayout
  }, children), wrapContent);
};
var _default = SliderModal;
exports.default = _default;
//# sourceMappingURL=SliderModalView.js.map