function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
import React, { useState, useEffect } from 'react';
import { View, useWindowDimensions } from 'react-native';
import ModalView from './ModalView';
import SliderModalView from './SliderModalView';
import EventRegister from './EvenRegister';
import { getAutoTransformWidth, getAutoTransformModalType } from '../functions';
import styles from '../styles';
const MainModal = props => {
  const {
    visible = true,
    wrapStyle,
    defaultModalProps
  } = props;
  const {
    width
  } = useWindowDimensions();
  const {
    containerStyle: defaultContainerStyle,
    wrapContainerStyle: defaultWrapContainerStyle,
    backdropStyle: defaultBackdropStyle,
    ..._defaultModalProps
  } = defaultModalProps || {};
  const [modalListState, setModalListState] = useState([]);
  useEffect(() => {
    EventRegister.on('open-nested-modal', modalProps => {
      setModalListState(_state => {
        return _state.concat(modalProps);
      });
    });
    EventRegister.on('close-nested-modal', args => {
      setModalListState(_state => {
        return _state.map(el => {
          if (el.id === args.id) {
            return {
              ...el,
              visible: false
            };
          }
          return el;
        });
      });
    });
    EventRegister.on('update-nested-modal', modalProps => {
      setModalListState(_state => {
        return _state.map(el => {
          if (el.id === modalProps.id) {
            return modalProps;
          }
          return el;
        });
      });
    });
    return () => {
      EventRegister.rm('open-nested-modal');
      EventRegister.rm('close-nested-modal');
      EventRegister.rm('update-nested-modal');
    };
  }, []);
  const _onCloseModal = modalProps => () => {
    var _modalProps$onClose;
    (_modalProps$onClose = modalProps.onClose) === null || _modalProps$onClose === void 0 || _modalProps$onClose.call(modalProps);
    setModalListState(_state => _state.filter(item => item.id !== modalProps.id));
  };
  if (!visible || modalListState == undefined || modalListState.length < 1) return null;
  return /*#__PURE__*/React.createElement(View, {
    style: [styles.modalWrapContainer, wrapStyle]
  }, modalListState.map(item => {
    const {
      id,
      modalType,
      containerStyle,
      wrapContainerStyle,
      backdropStyle,
      autoTransform,
      transformBreakPoint,
      ..._modalProps
    } = item;
    const _modalType = getAutoTransformModalType(!!autoTransform, modalType, width, transformBreakPoint);
    const _modalContentStyles = !!autoTransform && _modalType === 'fade' ? {
      width: getAutoTransformWidth(width, transformBreakPoint),
      paddingLeft: 0,
      paddingRight: 0
    } : undefined;
    if (_modalType === 'slide') {
      return /*#__PURE__*/React.createElement(SliderModalView, _extends({
        key: id,
        containerStyle: [defaultContainerStyle, containerStyle],
        wrapContainerStyle: [defaultWrapContainerStyle, wrapContainerStyle],
        backdropStyle: [defaultBackdropStyle, backdropStyle]
      }, _defaultModalProps, _modalProps, {
        onClose: _onCloseModal(item)
      }));
    }
    return /*#__PURE__*/React.createElement(ModalView, _extends({
      key: id,
      containerStyle: [defaultContainerStyle, _modalContentStyles, containerStyle],
      wrapContainerStyle: [defaultWrapContainerStyle, wrapContainerStyle],
      backdropStyle: [defaultBackdropStyle, backdropStyle]
    }, _defaultModalProps, _modalProps, {
      onClose: _onCloseModal(item)
    }));
  }));
};
export default MainModal;
//# sourceMappingURL=ModalSection.js.map