import React, { useState, useEffect, useRef } from 'react';
import { View, Animated, useWindowDimensions } from 'react-native';
import { TouchableWithoutFeedback } from 'react-native-ntc-pressable';
import { generateId } from '../functions';
import styles from '../styles';
const ANIMATION_BOUNCINESS = 1;
const ANIMATION_SPEED = 15;
const ANIMATION_DURATION = 200;
const SliderModal = props => {
  const {
    containerStyle,
    wrapContainerStyle,
    backdropStyle,
    id,
    visible,
    close,
    onOpen,
    onDidOpen,
    onClose,
    onMainContentLayout,
    children,
    wrapContent,
    keyboardHeight,
    safeAreaInsets,
    blurToClose = true,
    maxHeight = '95%'
  } = props;
  const myLocalData = useRef({
    isRunningAnimation: false,
    id: id || generateId()
  });
  const {
    height
  } = useWindowDimensions();
  const [state] = useState({
    backdropOpacity: new Animated.Value(0),
    contentTranslateY: new Animated.Value(height)
  });
  const [contentLayout, setContentLayout] = useState({
    height
  });
  const [visibleState, setVisibleState] = useState(false);
  useEffect(() => {
    if (visible) {
      if (myLocalData.current.isRunningAnimation) {
        _dropAnimation();
        setTimeout(() => {
          _openModal();
        }, 100);
      } else {
        _openModal();
      }
    } else {
      if (myLocalData.current.isRunningAnimation) {
        _dropAnimation();
        setTimeout(() => {
          _closeModal();
        }, 100);
      } else {
        _closeModal();
      }
    }
  }, [visible]);
  const _openModal = () => {
    setVisibleState(true);
    onOpen === null || onOpen === void 0 || onOpen(id);
    myLocalData.current.isRunningAnimation = true;
    Animated.timing(state.backdropOpacity, {
      toValue: 1,
      duration: ANIMATION_DURATION,
      useNativeDriver: true
    }).start();
    Animated.spring(state.contentTranslateY, {
      toValue: 0,
      speed: ANIMATION_SPEED,
      bounciness: ANIMATION_BOUNCINESS,
      useNativeDriver: true
    }).start(() => {
      myLocalData.current.isRunningAnimation = false;
      onDidOpen === null || onDidOpen === void 0 || onDidOpen(id);
    });
  };
  const _closeModal = () => {
    myLocalData.current.isRunningAnimation = true;
    Animated.spring(state.contentTranslateY, {
      toValue: contentLayout.height,
      speed: ANIMATION_SPEED,
      bounciness: ANIMATION_BOUNCINESS,
      useNativeDriver: true
    }).start();
    Animated.timing(state.backdropOpacity, {
      toValue: 0,
      duration: ANIMATION_DURATION,
      delay: 0,
      useNativeDriver: true
    }).start(() => {
      setVisibleState(false);
      myLocalData.current.isRunningAnimation = false;
      onClose === null || onClose === void 0 || onClose(id);
    });
  };
  const _dropAnimation = () => {
    // @ts-ignore
    Animated.timing(state.backdropOpacity).stop();
    // @ts-ignore
    Animated.spring(state.contentTranslateY).stop();
  };
  const _onBackdropPress = () => {
    close === null || close === void 0 || close();
  };
  const _onModalContentLayout = e => {
    var _e$nativeEvent;
    e.persist();
    onMainContentLayout === null || onMainContentLayout === void 0 || onMainContentLayout(e, id);
    const layout = (_e$nativeEvent = e.nativeEvent) === null || _e$nativeEvent === void 0 ? void 0 : _e$nativeEvent.layout;
    setContentLayout(layout);
  };
  if (!visibleState) return null;
  return /*#__PURE__*/React.createElement(Animated.View, {
    style: [styles.modalWrapContainer, {
      opacity: state.backdropOpacity,
      justifyContent: 'flex-end'
    }, wrapContainerStyle]
  }, /*#__PURE__*/React.createElement(TouchableWithoutFeedback, {
    onPress: _onBackdropPress,
    disabled: !blurToClose
  }, /*#__PURE__*/React.createElement(View, {
    style: [{
      height: '100%',
      width: '100%',
      position: 'absolute',
      top: 0,
      backgroundColor: 'rgba(0,0,0,0.7)'
    }, backdropStyle]
  })), /*#__PURE__*/React.createElement(Animated.View, {
    style: [{
      backgroundColor: '#ffffff',
      width: '100%',
      maxHeight,
      overflow: 'hidden',
      borderTopLeftRadius: 20,
      borderTopRightRadius: 20,
      flexShrink: 1,
      transform: [{
        translateY: state.contentTranslateY
      }]
    }, !!safeAreaInsets && {
      marginTop: safeAreaInsets.top,
      paddingBottom: safeAreaInsets.bottom,
      paddingLeft: safeAreaInsets.left,
      paddingRight: safeAreaInsets.right
    }, containerStyle, !!keyboardHeight && {
      paddingBottom: keyboardHeight
    }],
    onLayout: _onModalContentLayout
  }, children), wrapContent);
};
export default SliderModal;
//# sourceMappingURL=SliderModalView.js.map